Module: Google::Cloud::ServiceDirectory

Defined in:
lib/google/cloud/service_directory.rb,
lib/google/cloud/service_directory/version.rb

Constant Summary collapse

VERSION =
"2.2.0".freeze

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.service_directory| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-service_directory library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :jitter (type: Numeric) - The jitter in seconds. Default: 1.0.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



231
232
233
234
235
# File 'lib/google/cloud/service_directory.rb', line 231

def self.configure
  yield ::Google::Cloud.configure.service_directory if block_given?

  ::Google::Cloud.configure.service_directory
end

.lookup_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for LookupService.

By default, this returns an instance of Google::Cloud::ServiceDirectory::V1::LookupService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the LookupService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the LookupService service. You can determine whether the method will succeed by calling lookup_service_available?.

About LookupService

Service Directory API for looking up service data at runtime.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



75
76
77
78
79
80
81
82
83
84
85
# File 'lib/google/cloud/service_directory.rb', line 75

def self.lookup_service version: :v1, transport: :grpc, &block
  require "google/cloud/service_directory/#{version.to_s.downcase}"

  package_name = Google::Cloud::ServiceDirectory
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::ServiceDirectory.const_get(package_name).const_get(:LookupService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.lookup_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the LookupService service is supported by the current client. If true, you can retrieve a client object by calling lookup_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the LookupService service, or if the versioned client gem needs an update to support the LookupService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/google/cloud/service_directory.rb', line 99

def self.lookup_service_available? version: :v1, transport: :grpc
  require "google/cloud/service_directory/#{version.to_s.downcase}"
  package_name = Google::Cloud::ServiceDirectory
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::ServiceDirectory.const_get package_name
  return false unless service_module.const_defined? :LookupService
  service_module = service_module.const_get :LookupService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.registration_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for RegistrationService.

By default, this returns an instance of Google::Cloud::ServiceDirectory::V1::RegistrationService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the RegistrationService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the RegistrationService service. You can determine whether the method will succeed by calling registration_service_available?.

About RegistrationService

Service Directory API for registering services. It defines the following resource model:

  • The API has a collection of Namespace resources, named projects/*/locations/*/namespaces/*.

  • Each Namespace has a collection of Service resources, named projects/*/locations/*/namespaces/*/services/*.

  • Each Service has a collection of Endpoint resources, named projects/*/locations/*/namespaces/*/services/*/endpoints/*.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



159
160
161
162
163
164
165
166
167
168
169
# File 'lib/google/cloud/service_directory.rb', line 159

def self.registration_service version: :v1, transport: :grpc, &block
  require "google/cloud/service_directory/#{version.to_s.downcase}"

  package_name = Google::Cloud::ServiceDirectory
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::ServiceDirectory.const_get(package_name).const_get(:RegistrationService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.registration_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the RegistrationService service is supported by the current client. If true, you can retrieve a client object by calling registration_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the RegistrationService service, or if the versioned client gem needs an update to support the RegistrationService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/google/cloud/service_directory.rb', line 183

def self.registration_service_available? version: :v1, transport: :grpc
  require "google/cloud/service_directory/#{version.to_s.downcase}"
  package_name = Google::Cloud::ServiceDirectory
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::ServiceDirectory.const_get package_name
  return false unless service_module.const_defined? :RegistrationService
  service_module = service_module.const_get :RegistrationService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end